==> kdelibs-debuginfo-4.14.12-1.tar.xz: usr/src/debug/kdelibs-4.14.12-1/kdewidgets/qrc_kdedeprecated.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/kdelibs/kdelibs-4.14.12-1.i686/src/kdelibs-4.14.12/kdewidgets/pics/keditlistbox.png
  0x0,0x0,0x1,0xe4,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x8,0x3,0x0,0x0,0x0,0xf3,0x6a,0x9c,0x9,
  0x0,0x0,0x0,0x4,0x67,0x41,0x4d,0x41,0x0,0x0,0xb1,0x8f,0xb,0xfc,0x61,0x5,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x12,0x0,0x0,0xb,0x12,
  0x1,0xd2,0xdd,0x7e,0xfc,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd2,0x3,
  0x19,0x13,0x2b,0x6,0x78,0xe0,0x30,0x34,0x0,0x0,0x0,0x90,0x50,0x4c,0x54,0x45,
  0x0,0x0,0x0,0xff,0xff,0xff,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0xf,0xb,0x6,0x13,0x9,0x4,0x16,0x7,0x0,0x1a,0xc,0x2,0x1c,0x15,
  0x12,0x1f,0x1e,0x1a,0x22,0xc,0x0,0x23,0x21,0x1c,0x25,0xd,0x0,0x2a,0xf,0x0,
  0x2c,0xf,0x0,0x2d,0x10,0x0,0x33,0x1d,0x10,0x3c,0x22,0x13,0x3e,0x3b,0x39,0x3f,
  0x24,0x14,0x48,0x47,0x3c,0x4b,0x49,0x4b,0x5f,0x3c,0x27,0x72,0x69,0x63,0x84,0x7e,
  0x78,0x8b,0x82,0x7d,0x8b,0x85,0x82,0x9c,0x9e,0x9b,0x9e,0x99,0x96,0xa6,0x9d,0x97,
  0xab,0xab,0xab,0xb1,0xb1,0xb1,0xb3,0xb3,0xb3,0xb7,0xb7,0xb7,0xb8,0xae,0xa9,0xd1,
  0xcc,0xc9,0xd5,0xd5,0xd5,0xda,0xd5,0xd2,0xe0,0xe0,0xe0,0xe2,0xe2,0xe2,0xe3,0xe3,
  0xe3,0xe5,0xe5,0xe5,0xf9,0xf9,0xf9,0xfd,0xfd,0xfd,0xfe,0xfe,0xfe,0xff,0xff,0xff,
  0x7d,0x9e,0xa0,0xf0,0x0,0x0,0x0,0x5,0x74,0x52,0x4e,0x53,0x0,0x0,0x6,0xb,
  0x11,0x4f,0xa2,0x83,0x3a,0x0,0x0,0x0,0x1,0x62,0x4b,0x47,0x44,0x0,0x88,0x5,
  0x1d,0x48,0x0,0x0,0x0,0xb9,0x49,0x44,0x41,0x54,0x78,0xda,0x85,0x91,0xe9,0xe,
  0x82,0x30,0x10,0x84,0x57,0x14,0xef,0x83,0x55,0xab,0x20,0x8,0x14,0x50,0x84,0xa,
  0xfb,0xfe,0x6f,0x67,0x1b,0x5a,0xae,0x98,0xf0,0xfd,0x69,0x33,0x99,0xcc,0xec,0x66,
  0x41,0xc2,0x70,0x0,0x3,0x85,0x8b,0x5e,0x10,0xf3,0x96,0x24,0xf4,0xd1,0x95,0x32,
  0x7a,0xe9,0x93,0x88,0x84,0xa1,0x2c,0x22,0x94,0x9,0x5e,0x2a,0xa8,0x4f,0x5d,0x51,
  0xc6,0x0,0x83,0x37,0xd9,0x1a,0xa2,0xe6,0xc9,0x11,0x30,0xfe,0x90,0xcd,0x49,0x61,
  0xcb,0x8f,0x90,0xd8,0x24,0x65,0x2e,0x26,0x64,0x13,0xc2,0xb5,0xdc,0x65,0x73,0x5,
  0x69,0x99,0x78,0x83,0xa9,0x1c,0xb9,0x4d,0xf6,0x77,0xa2,0x52,0x21,0xe5,0x99,0xae,
  0x1c,0xb9,0x41,0x57,0x6c,0x87,0x6e,0x53,0x79,0xff,0x9f,0xbd,0x4,0x4c,0x8c,0xbb,
  0x93,0xc5,0x1e,0x30,0x2c,0xeb,0xf1,0x96,0x2,0x81,0xf9,0x45,0xd5,0xce,0xad,0xb9,
  0x5e,0x0,0x30,0xea,0xb6,0x6c,0xd8,0xad,0x17,0xea,0x68,0x59,0x4e,0x3d,0x5e,0x8f,
  0xcd,0xd9,0xea,0x4e,0xec,0x9c,0xd0,0x39,0xdc,0x56,0x47,0x64,0x73,0xb,0x7e,0x2b,
  0x1e,0x35,0xd0,0x24,0xf5,0x48,0xd3,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,
  0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // pics
  0x0,0x4,
  0x0,0x7,0x6f,0xa3,
  0x0,0x70,
  0x0,0x69,0x0,0x63,0x0,0x73,
    // keditlistbox.png
  0x0,0x10,
  0x8,0x11,0x2c,0xc7,
  0x0,0x6b,
  0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x74,0x0,0x6c,0x0,0x69,0x0,0x73,0x0,0x74,0x0,0x62,0x0,0x6f,0x0,0x78,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/pics
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/pics/keditlistbox.png
  0x0,0x0,0x0,0xe,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_kdedeprecated)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_kdedeprecated))

int QT_MANGLE_NAMESPACE(qCleanupResources_kdedeprecated)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_kdedeprecated))

==> kdelibs-debuginfo-4.14.13-1.tar.xz: usr/src/debug/kdelibs-4.14.13-1/kdewidgets/qrc_kdedeprecated.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/kdelibs/kdelibs-4.14.13-1.x86_64/src/kdelibs-4.14.13/kdewidgets/pics/keditlistbox.png
  0x0,0x0,0x1,0xe4,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x16,0x0,0x0,0x0,0x16,0x8,0x3,0x0,0x0,0x0,0xf3,0x6a,0x9c,0x9,
  0x0,0x0,0x0,0x4,0x67,0x41,0x4d,0x41,0x0,0x0,0xb1,0x8f,0xb,0xfc,0x61,0x5,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x12,0x0,0x0,0xb,0x12,
  0x1,0xd2,0xdd,0x7e,0xfc,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd2,0x3,
  0x19,0x13,0x2b,0x6,0x78,0xe0,0x30,0x34,0x0,0x0,0x0,0x90,0x50,0x4c,0x54,0x45,
  0x0,0x0,0x0,0xff,0xff,0xff,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0xf,0xb,0x6,0x13,0x9,0x4,0x16,0x7,0x0,0x1a,0xc,0x2,0x1c,0x15,
  0x12,0x1f,0x1e,0x1a,0x22,0xc,0x0,0x23,0x21,0x1c,0x25,0xd,0x0,0x2a,0xf,0x0,
  0x2c,0xf,0x0,0x2d,0x10,0x0,0x33,0x1d,0x10,0x3c,0x22,0x13,0x3e,0x3b,0x39,0x3f,
  0x24,0x14,0x48,0x47,0x3c,0x4b,0x49,0x4b,0x5f,0x3c,0x27,0x72,0x69,0x63,0x84,0x7e,
  0x78,0x8b,0x82,0x7d,0x8b,0x85,0x82,0x9c,0x9e,0x9b,0x9e,0x99,0x96,0xa6,0x9d,0x97,
  0xab,0xab,0xab,0xb1,0xb1,0xb1,0xb3,0xb3,0xb3,0xb7,0xb7,0xb7,0xb8,0xae,0xa9,0xd1,
  0xcc,0xc9,0xd5,0xd5,0xd5,0xda,0xd5,0xd2,0xe0,0xe0,0xe0,0xe2,0xe2,0xe2,0xe3,0xe3,
  0xe3,0xe5,0xe5,0xe5,0xf9,0xf9,0xf9,0xfd,0xfd,0xfd,0xfe,0xfe,0xfe,0xff,0xff,0xff,
  0x7d,0x9e,0xa0,0xf0,0x0,0x0,0x0,0x5,0x74,0x52,0x4e,0x53,0x0,0x0,0x6,0xb,
  0x11,0x4f,0xa2,0x83,0x3a,0x0,0x0,0x0,0x1,0x62,0x4b,0x47,0x44,0x0,0x88,0x5,
  0x1d,0x48,0x0,0x0,0x0,0xb9,0x49,0x44,0x41,0x54,0x78,0xda,0x85,0x91,0xe9,0xe,
  0x82,0x30,0x10,0x84,0x57,0x14,0xef,0x83,0x55,0xab,0x20,0x8,0x14,0x50,0x84,0xa,
  0xfb,0xfe,0x6f,0x67,0x1b,0x5a,0xae,0x98,0xf0,0xfd,0x69,0x33,0x99,0xcc,0xec,0x66,
  0x41,0xc2,0x70,0x0,0x3,0x85,0x8b,0x5e,0x10,0xf3,0x96,0x24,0xf4,0xd1,0x95,0x32,
  0x7a,0xe9,0x93,0x88,0x84,0xa1,0x2c,0x22,0x94,0x9,0x5e,0x2a,0xa8,0x4f,0x5d,0x51,
  0xc6,0x0,0x83,0x37,0xd9,0x1a,0xa2,0xe6,0xc9,0x11,0x30,0xfe,0x90,0xcd,0x49,0x61,
  0xcb,0x8f,0x90,0xd8,0x24,0x65,0x2e,0x26,0x64,0x13,0xc2,0xb5,0xdc,0x65,0x73,0x5,
  0x69,0x99,0x78,0x83,0xa9,0x1c,0xb9,0x4d,0xf6,0x77,0xa2,0x52,0x21,0xe5,0x99,0xae,
  0x1c,0xb9,0x41,0x57,0x6c,0x87,0x6e,0x53,0x79,0xff,0x9f,0xbd,0x4,0x4c,0x8c,0xbb,
  0x93,0xc5,0x1e,0x30,0x2c,0xeb,0xf1,0x96,0x2,0x81,0xf9,0x45,0xd5,0xce,0xad,0xb9,
  0x5e,0x0,0x30,0xea,0xb6,0x6c,0xd8,0xad,0x17,0xea,0x68,0x59,0x4e,0x3d,0x5e,0x8f,
  0xcd,0xd9,0xea,0x4e,0xec,0x9c,0xd0,0x39,0xdc,0x56,0x47,0x64,0x73,0xb,0x7e,0x2b,
  0x1e,0x35,0xd0,0x24,0xf5,0x48,0xd3,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,
  0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // pics
  0x0,0x4,
  0x0,0x7,0x6f,0xa3,
  0x0,0x70,
  0x0,0x69,0x0,0x63,0x0,0x73,
    // keditlistbox.png
  0x0,0x10,
  0x8,0x11,0x2c,0xc7,
  0x0,0x6b,
  0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x74,0x0,0x6c,0x0,0x69,0x0,0x73,0x0,0x74,0x0,0x62,0x0,0x6f,0x0,0x78,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/pics
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/pics/keditlistbox.png
  0x0,0x0,0x0,0xe,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_kdedeprecated)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_kdedeprecated))

int QT_MANGLE_NAMESPACE(qCleanupResources_kdedeprecated)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_kdedeprecated))
